# =================================================================
# Licensed Materials - Property of IBM
#
# (c) Copyright IBM Corp. 2024 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# =================================================================

from datetime import datetime
import logging as LOG
import ast
import http.client
import urllib.parse
import ssl


def get_current_datetime():
    current_datetime = datetime.now().strftime("%Y%m%d%H%M%S")
    return current_datetime


"""
def get_pvc_services_status(pvc_ip, pvc_services_status_port):
    try:
        pvc_url = "https://" + pvc_ip + ":" + pvc_services_status_port
        pvc_srvcs_resp = requests.get(pvc_url,
            headers={"Content-Type": "application/json"},
            verify=False)
        return pvc_srvcs_resp.json()
    except Exception as exc:
        LOG.error(f"Error in getting powervc services status : {exc}")
        return None
"""


def get_pvc_services_status(pvc_ip, pvc_services_status_port):
    try:
        pvc_url = "https://" + pvc_ip + ":" + pvc_services_status_port
        url_parts = urllib.parse.urlparse(pvc_url)
        conn = http.client.HTTPSConnection(
            url_parts.netloc, context=ssl._create_unverified_context())

        conn.request("GET", url_parts.path)

        response = conn.getresponse()
        if response.status == 200:
            response_data = ''
            while True:
                # Reading data in chunks of 4mb
                chunk = response.read(4096)
                if not chunk:
                    break
                response_data += chunk.decode('utf-8')
            status = ast.literal_eval(response_data)
            return status
        else:
            LOG.error(
                "Error in get_pvc_services_status :",
                response.status,
                response.reason)
            return None
    except Exception as exc:
        LOG.error(f"Error in getting powervc services status {exc}")
        return None
    finally:
        conn.close()


"""
def get_pvc_services_status(pvc_ip, pvc_services_status_port):
    try:
        pvc_url = "https://" + pvc_ip + ":" + pvc_services_status_port
        curl_command = ["curl", "-X", "GET", pvc_url, "-k"]

        # Execute the curl command
        process = subprocess.Popen(curl_command,
                                   stdout=subprocess.PIPE,
                                   stderr=subprocess.PIPE)

        # Capture the output and error streams
        output, error = process.communicate()
        if error:
            LOG.error(f"Error in getting powervc services status: {error}")
        output = output.decode("utf-8")
        output = output.strip('"').strip('\r\n')
        status = ast.literal_eval(output)
        return status
    except Exception as exc:
        LOG.error(f"Error in getting powervc services status {exc}")
        return None
"""
