# =================================================================
# Licensed Materials - Property of IBM
#
# (c) Copyright IBM Corp. 2024 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# =================================================================

from powervc_validation_toolkit.results import test_results
from powervc_validation_toolkit.conf import config_object


class BaseTest:
    def __init__(self, name, config, blacklist_hosts, **args):
        self.name = name
        self.config = config
        self.results = {}
        self.test_results = test_results
        self.isSuccess = True
        for arg in args.keys():
            self.__dict__[arg] = args[arg]
        self.conf = self.get_config_object(self.name)
        self.blacklist_hosts = self.conf.blacklist_hosts.union(
            blacklist_hosts)

    def get_config_object(self, name):
        attributes = {}
        blacklist_hosts = set()
        for section in [name, 'settings', 'Default']:
            options = self.config.options(section)
            attr = {
                option: self.config.get(
                    section, option) for option in options}
            if 'blacklist_hosts' in attr:
                for item in attr['blacklist_hosts'].split(','):
                    host = item.strip()
                    if host:
                        blacklist_hosts.add(host)
            attr['blacklist_hosts'] = blacklist_hosts
            attributes.update(attr)
        return config_object.ConfigObject(**attributes)

    def setUp(self, **args):
        pass

    def get_results(self):
        pass
